from HackerGprat import clear
from pytube import YouTube
import os

def yt_download(videourl, path="./Output"):

    clear()
    
    print("Connecting...")
    
    yt = YouTube(videourl)
    yt = yt.streams.filter(progressive=True, file_extension='mp4').order_by('resolution').desc().first()
    
    if not os.path.exists(path):
        print("Creating Folder...")
        os.makedirs(path)

    print("Downloading...")
    yt.download(path)
    print("SucessFully Downloaded...")



# url = 'https://www.youtube.com/watch?v=r2giUilvkBQ&list=PLC3y8-rFHvwg2-q6Kvw3Tl_4xhxtIaNlY&index=45'
# yt_download( url )

# urls = []


def yt( videoUrl, path="./Output"):
    
    if type( videoUrl ) == str:
        yt_download(videourl)
        
    elif type( videoUrl ) == list:
        for link in videoUrl:
            yt_download( link )
    else:
        print("See The Docs & Try Again")






# from binance import Client
# import pandas as pd 


def getminutedata( symbol, interval='1m', lookback="300" ):

    from binance import Client
    import pandas as pd 
    
    frame = pd.DataFrame( client.get_historical_klines( symbol , interval, lookback + " min ago UTC") )
    
    frame = frame.iloc[ : , : 6]
    frame.columns = ['Time', 'Open', 'High', 'Lows', 'Close', 'Volume']
    
    frame = frame.set_index('Time')
    frame.index = pd.to_datetime( frame.index, unit='ms' )
    
    frame = frame.astype( float )
    return frame

    






# ---------------------------------------------
def fib(n):   # return Fibonacci series up to n
    result = []
    a, b = 0, 1
    while a < n:
        result.append(a)
        a, b = b, a+b
    return result


# -------------------------------------------



if __name__ == '__main__':
    pass



import requests as req
from bs4 import BeautifulSoup as bs



# -------------------------------
# connection_code code
def connection_code( url ):
    '''
    # usage #200 = connected
    # Q. prompt if we are connect

    if (connection_code(url) == 200):
        print("Connected Successfully...")

    '''
    try:
        r = req.get( url )
        return r.status_code
    except:
        return( str( "Error Found in url" ) )

# url = 'https://www.pyathon.org'

# print( connection_code(url) )

# if (connection_code(url) == 200):
#     print("Connected Successfully...")
# else:
#     print("Check Url... Error Found.")
# -------------------------------




# -------------------------------
# check connection print string

def isConnected(url):
    if ( connection_code(url) == 200 ):
        return str("Connected Sucessfully....")
    else:
        error = connection_code(url)
        return str("google -> Error code ", error)


# print( isConnected(url) )

# -------------------------------
# -------------------------------
# -------------------------------


if __name__ == '__main__':
    pass
